summaryrefslogtreecommitdiff
path: root/driver_oncore.c
diff options
context:
space:
mode:
authorHTJ <address@hidden>2016-03-20 21:56:47 +0100
committerEric S. Raymond <esr@thyrsus.com>2016-03-22 18:59:00 -0400
commitd46da8954e81fe8eea6e7411fecfc62f44596033 (patch)
tree03d6b35bbe15c4d53805ca4aa41d2e63f4642aec /driver_oncore.c
parent4f4e24d8330cd3b6eeed79dc1bcb6dd387d3581a (diff)
downloadgpsd-d46da8954e81fe8eea6e7411fecfc62f44596033.tar.gz
Introduce the flag GOODTIME_IS...
...to mark that the device has a good time even if it does not report a position fix. Used by the OnCore driver, e.g. when in position hold mode. scons check passes
Diffstat (limited to 'driver_oncore.c')
-rw-r--r--driver_oncore.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/driver_oncore.c b/driver_oncore.c
index f4338b77..43f65f0a 100644
--- a/driver_oncore.c
+++ b/driver_oncore.c
@@ -176,9 +176,9 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
}
/* bit 2 of the status word: using for time solution */
if (status & 0x02)
- mask |= PPSTIME_IS;
+ mask |= PPSTIME_IS | GOODTIME_IS;
/*
* The PPSTIME_IS mask bit exists distinctly from TIME_SET exactly
* so an OnCore running in time-service mode (and other GPS clocks)
* can signal that it's returning time even though no position fixes
* have been available.
@@ -176,9 +176,9 @@ oncore_msg_navsol(struct gps_device_t *session, unsigned char *buf,
/*
- * The PPSTIME_IS mask bit exists distinctly from TIME_SET exactly
+ * The GOODTIME_IS mask bit exists distinctly from TIME_SET exactly
* so an OnCore running in time-service mode (and other GPS clocks)
* can signal that it's returning time even though no position fixes